@@ -1,6 +1,6 @@
 # important_changes.pl - This script prints important changes in Sympa since last install
 # It is based on the NEWS ***** entries
-# RCS Identication ; $Revision: 4868 $ ; $Date: 2008-03-03 17:54:09 +0100 (lun, 03 mar 2008) $ 
+# RCS Identication ; $Revision: 5900 $ ; $Date: 2009-06-16 14:39:21 +0200 (mar 16 jun 2009) $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -23,67 +23,39 @@
 ## Print important changes in Sympa since last install
 ## It is based on the NEWS ***** entries
 
-my ($first_install, $current_version, $previous_version);
+use strict;
+use Getopt::Long;
 
-$current_version = $ENV{'SYMPA_VERSION'};
+my %options;
+GetOptions(
+    \%options,
+    'current=s',
+    'previous=s',
+);
 
-unless ($current_version) {
-    print STDERR "Could not get current Sympa version\n";
-    exit -1;
-}
+die "no current given version, aborting" unless $options{current};
 
-## Get previous installed version of Sympa
-unless (open VERSION, "$ENV{'DESTDIR'}$ENV{'BINDIR'}/Version.pm") {
-    print STDERR "Could not find previous install of Sympa ; assuming first install\n";
+if (!$options{previous}) {
+    print STDERR "No previous version given, assuming first installation";
     exit 0;
 }
 
-unless ($first_install) {
-    while (<VERSION>) {
-	if (/^(our )?\$Version = \'(\S+)\'\;/) {
-	    $previous_version = $2;
-	    last;
-	}
-    }
-}
-close VERSION;
-
-## Create the data_structure.version file if none exists
-my $version_file = "$ENV{'ETCDIR'}/data_structure.version";
-if ($ENV{'ETCDIR'} && ! -f $version_file) {
-    ## Create missing directory
-    unless (-d $ENV{'ETCDIR'}) {
-	print STDERR "Creating missing directory %s...\n", $ENV{'ETCDIR'};
-	unless (mkdir $ENV{'ETCDIR'}, 0770) {
-	    print STDERR "Failed to create $ENV{'ETCDIR'} directory : $!\n";
-	    exit -1;
-	}
-    }
-    
-    print STDERR "Creating missing $version_file\n";
-    
-    unless (open VFILE, ">$version_file") {
-	printf STDERR "Unable to write %s ; sympa.pl needs write access on %s directory : %s\n", $version_file, $ENV{'ETCDIR'}, $!;
-	return undef;
-    }
-    printf VFILE "# This file is automatically created by sympa.pl after installation\n# Unless you know what you are doing, you should not modify it\n";
-    if ($previous_version) {
-	printf VFILE "%s\n", $previous_version;
-    }else { 
-	printf VFILE "%s\n", $current_version;
-    }
-    close VFILE;
-}
-
-`chown $ENV{'USER'} $version_file`;
-`chgrp $ENV{'GROUP'} $version_file`;
+my $previous_version = $options{previous};
+my $current_version = $options{current};
 
+# exit immediatly if previous version is higher or equal
 if (($previous_version eq $current_version) ||
     &higher($previous_version,$current_version)){
     exit 0;
 }
 
-print "You are upgrading from Sympa $previous_version\nYou should read CAREFULLY the changes listed below ; they might be incompatible changes :\n<RETURN>";
+print <<EOF;
+You are upgrading from Sympa $previous_version
+You should read CAREFULLY the changes listed below
+They might be incompatible changes:
+<RETURN>
+EOF
+
 my $wait = <STDIN>;
 
 ## Extracting Important changes from release notes
@@ -96,7 +68,7 @@ while (<NOTES>) {
 	    &higher($previous_version,$v)
 	    ) {
 	    last;
-	}elsif ($v eq $current_version) {
+	}else{
 	    $ok = 1;
 	}
     }
@@ -114,7 +86,7 @@ while (<NOTES>) {
 }
 close NOTES;
 print "<RETURN>";
-my $wait = <STDIN> unless ($ENV{'DESTDIR'}); ## required for package building
+my $wait = <STDIN>;
 
 sub higher {
     my ($v1, $v2) = @_;
@@ -126,7 +98,7 @@ sub higher {
     my $max = $#tab1;
     $max = $#tab2 if ($#tab2 > $#tab1);
 
-    for $i (0..$max) {
+    for my $i (0..$max) {
     
         if ($tab1[0] =~ /^(\d*)a$/) {
             $tab1[0] = $1 - 0.5;
