@@ -27,7 +27,6 @@ use Digest::MD5;
 use POSIX;
 use CGI::Cookie;
 use Time::Local;
-use Text::Wrap;
 
 use Log;
 use Conf;
@@ -449,12 +448,13 @@ sub list_sessions {
 sub get_session_cookie {
     my $http_cookie = shift;
 
-    my %cookies = parse CGI::Cookie($http_cookie);
-        
-    foreach (keys %cookies) {
-	my $cookie = $cookies{$_};
-	next unless ($cookie->name eq 'sympa_session');
-	return ($cookie->value);
+    if ($http_cookie =~/\S+/g) {
+	my %cookies = parse CGI::Cookie($http_cookie);
+	foreach (keys %cookies) {
+	    my $cookie = $cookies{$_};
+	    next unless ($cookie->name eq 'sympa_session');
+	    return ($cookie->value);
+	}
     }
 
     return (undef);
